;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ivy-prescient" "20250816.19"
  "Prescient.el + Ivy."
  '((emacs     "25.1")
    (prescient "6.1.0")
    (ivy       "0.11.0"))
  :url "https://github.com/raxod502/prescient.el"
  :commit "87e2d2f2ddf24f591a5f70cc90d2afb4537caa18"
  :revdesc "87e2d2f2ddf2"
  :keywords '("extensions")
  :authors '(("Radian LLC" . "contact+prescient@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+prescient@radian.codes")))
